function [freq, ampl] = subei(signal, f)
%
% This function takes a signal and generates its frequency plot
% as per the fft method.
%
% Function `subei` takes as input:
% `signal`, the 'y-axis' data
% `f`,   	the sampling frequency
%
% Function generates output:
% `freq`,   the frequencies the fft can differentiate on
% `ampl`,   the calculated amplitudes of the frequencies in `freq`

%clear all figures
clf;

t = 1 / f; % sampling time
length = size( signal, 2 ); %signal length

%construct time vector
time = (0:length-1); % it should have equal entries to the signal vector
time = time*t;  % time interval is t

%plot received vector
figure( 1 );
plot( time, signal );
title( 'original signal' );
xlabel( 'time (seconds)' );
ylabel( 'signal' );

nextpow = nextpow2( length ); %find the lowest integer x for which length<2^x

%find the amplitude vector
ampl = fft( signal, 2^nextpow ); %do the fft transformation using zero fill
ampl = ampl( 1:( 2^( nextpow - 1 ) ) ); % fft repeats itself after 2^nextpow/2 entries
ampl = 2*abs( ampl ); %calculate exact frequency amplitude

%find the frequency values
freq = f / 2 * linspace( 0,1, 2^(nextpow - 1) ); %fft diff. between 2^nextpow/2 frequencies, with max frequency being f/2

%plot frequecies
figure( 2 );
plot( freq, ampl );
title( 'Amplitude spectrum of signal' );
xlabel( 'Frequency (Hz)' );
ylabel( 'Amplitude' );
